class StringToolsFpat:
    def __init__(self):
        pass

    @staticmethod
    def lower(string: str):
        """
        Convert string to lower case

        Args:
            param1 (string): The string to be converted

        Returns:
            str


        """

        return string.lower()

    @staticmethod
    def upper(string: str):
        """
        Convert string to upper case

        Args:
            param1 (string): The string to be converted

        Returns:
            str


        """

        return string.upper()
